==> skill-core-1.12.3-sources.jar: com/ptteng/sca/common/skill/client/UserArticleRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.skill.model.UserArticleRelation;
import com.ptteng.common.skill.service.UserArticleRelationService;

import java.util.List;
import java.util.Map;

public class UserArticleRelationSCAClient implements UserArticleRelationService {

    private UserArticleRelationService userArticleRelationService;

	public UserArticleRelationService getUserArticleRelationService() {
		return userArticleRelationService;
	}
	
	
	public void setUserArticleRelationService(UserArticleRelationService userArticleRelationService) {
		this.userArticleRelationService =userArticleRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserArticleRelation userArticleRelation)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.insert(userArticleRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserArticleRelation> insertList(List<UserArticleRelation> userArticleRelationList)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.insertList(userArticleRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserArticleRelation userArticleRelation)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.update(userArticleRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserArticleRelation> userArticleRelationList)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.updateList(userArticleRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserArticleRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserArticleRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getUserArticleRelationIdByUidAndAidAndType(Long uid,Long aid,Integer type)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getUserArticleRelationIdByUidAndAidAndType(uid,aid,type);
	
	
	}

	@Override
	public Long getUserArticleRelationIdByUidAndAidAndTypeAndWeather(Long uid, Long aid, Integer type, Integer weather) throws ServiceException, ServiceDaoException {
		return userArticleRelationService.getUserArticleRelationIdByUidAndAidAndTypeAndWeather(uid, aid, type, weather);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserArticleRelationIdsByUidAndTypeAndWhether(Long uid,Integer type,Integer whether,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getUserArticleRelationIdsByUidAndTypeAndWhether(uid,type,whether,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserArticleRelationIdsByAidAndTypeAndWhether(Long aid,Integer type,Integer whether,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getUserArticleRelationIdsByAidAndTypeAndWhether(aid,type,whether,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserArticleRelationIdsByUidAndTypeAndWhether(Long uid,Integer type,Integer whether)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.countUserArticleRelationIdsByUidAndTypeAndWhether(uid,type,whether);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserArticleRelationIdsByAidAndTypeAndWhether(Long aid,Integer type,Integer whether)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.countUserArticleRelationIdsByAidAndTypeAndWhether(aid,type,whether);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserArticleRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userArticleRelationService.getUserArticleRelationIds(start, limit);
	}

	@Override
	public Integer countUserArticleRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userArticleRelationService.countUserArticleRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userArticleRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userArticleRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userArticleRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userArticleRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> skill-core-30.1.3-sources.jar: com/ptteng/sca/common/skill/client/UserArticleRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.skill.model.UserArticleRelation;
import com.ptteng.common.skill.service.UserArticleRelationService;

import java.util.List;
import java.util.Map;

public class UserArticleRelationSCAClient implements UserArticleRelationService {

    private UserArticleRelationService userArticleRelationService;

	public UserArticleRelationService getUserArticleRelationService() {
		return userArticleRelationService;
	}
	
	
	public void setUserArticleRelationService(UserArticleRelationService userArticleRelationService) {
		this.userArticleRelationService =userArticleRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserArticleRelation userArticleRelation)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.insert(userArticleRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserArticleRelation> insertList(List<UserArticleRelation> userArticleRelationList)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.insertList(userArticleRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserArticleRelation userArticleRelation)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.update(userArticleRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserArticleRelation> userArticleRelationList)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.updateList(userArticleRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserArticleRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserArticleRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getUserArticleRelationIdByUidAndAidAndTypeAndTargetType(Long uid,Long aid,Integer type,Integer targetType)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getUserArticleRelationIdByUidAndAidAndTypeAndTargetType(uid,aid,type,targetType);
	
	
	}

	@Override
	public Long getUserArticleRelationIdByUidAndAidAndTypeAndWeather(Long uid, Long aid, Integer type, Integer weather) throws ServiceException, ServiceDaoException {
		return userArticleRelationService.getUserArticleRelationIdByUidAndAidAndTypeAndWeather(uid, aid, type, weather);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserArticleRelationIdsByUidAndTypeAndWhether(Long uid,Integer type,Integer whether,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getUserArticleRelationIdsByUidAndTypeAndWhether(uid,type,whether,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserArticleRelationIdsByAidAndTypeAndWhether(Long aid,Integer type,Integer whether,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.getUserArticleRelationIdsByAidAndTypeAndWhether(aid,type,whether,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserArticleRelationIdsByUidAndTypeAndWhether(Long uid,Integer type,Integer whether)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.countUserArticleRelationIdsByUidAndTypeAndWhether(uid,type,whether);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserArticleRelationIdsByAidAndTypeAndWhether(Long aid,Integer type,Integer whether)throws ServiceException, ServiceDaoException{
		
		return userArticleRelationService.countUserArticleRelationIdsByAidAndTypeAndWhether(aid,type,whether);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserArticleRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userArticleRelationService.getUserArticleRelationIds(start, limit);
	}

	@Override
	public Integer countUserArticleRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userArticleRelationService.countUserArticleRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userArticleRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userArticleRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userArticleRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userArticleRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}
